"""
Problem 7 BST Height Solution
Language:  Python 3.x
Author:  Mark Fienup
NOTE:  READ_FILE = False means read from standard input; True means read from file.
NOTE:  WRITE_FILE = False means write to standard output; True means write to file.
"""
import sys

READ_FILE = False
IN_FILE_OPENED = False
IN_FILE_NAME = "prob7_in.txt"
IN_FILE = None

WRITE_FILE = False
OUT_FILE_OPENED = False
OUT_FILE_NAME = "prob7_out.txt"
OUT_FILE = None

class TreeNode:
   def __init__(self,key,val,left=None,right=None,
                                       parent=None):
      self.key = key
      self.payload = val
      self.leftChild = left
      self.rightChild = right
      self.parent = parent

   def hasLeftChild(self):
      return self.leftChild

   def hasRightChild(self):
      return self.rightChild
    
   def isLeftChild(self):
      return self.parent and \
             self.parent.leftChild == self

   def isRightChild(self):
      return self.parent and \
             self.parent.rightChild == self

   def isRoot(self):
      return not self.parent

   def isLeaf(self):
      return not (self.rightChild or self.leftChild)

   def hasAnyChildren(self):
      return self.rightChild or self.leftChild

   def hasBothChildren(self):
      return self.rightChild and self.leftChild


class BinarySearchTree:

    def __init__(self):
        self.root = None
        self.size = 0
    
    def __len__(self):
        return self.size


    def put(self,key,val):
        if self.root:
            self._put(key,val,self.root)
        else:
            self.root = TreeNode(key,val)
        self.size = self.size + 1

    def _put(self,key,val,currentNode):
        if key < currentNode.key:
            if currentNode.hasLeftChild():
                self._put(key,val,currentNode.leftChild)
            else:
                currentNode.leftChild = TreeNode(key,val,
                                          parent=currentNode)
        elif key > currentNode.key:
            if currentNode.hasRightChild():
                self._put(key,val,currentNode.rightChild)
            else:
                currentNode.rightChild = TreeNode(key,val,
                                          parent=currentNode)
        else:
            currentNode.payload = val
            self.size -= 1



    def height(self):
        
        def heightHelper(subtreeRoot):
            """ Recursive helper method to determine the height of the BST. """
            if subtreeRoot == None:
                return -1

            return max(heightHelper(subtreeRoot.rightChild),heightHelper(subtreeRoot.leftChild)) + 1

        return heightHelper(self.root)


def main():
  
    numberOfCases = int(nextLine())
    #print(numberOfCases)
    
    for case in range(1, numberOfCases+1):
        BSTInfo = nextLine().split()
        numberOfValues = int(BSTInfo[0])
        bst = BinarySearchTree()
        for index in range(1, numberOfValues+1):
            value = int(BSTInfo[index])
            bst.put(value, None)
           
        resultStr = "Case " + str(case) + ":"
        resultStr += " " + str(bst.height())
                
        writeLine(resultStr)

    if WRITE_FILE:
        OUT_FILE.close()

def writeLine(line):
    global OUT_FILE_OPENED
    global OUT_FILE
    if WRITE_FILE:
        if not OUT_FILE_OPENED:
            OUT_FILE = open(OUT_FILE_NAME, "w")
            OUT_FILE_OPENED = True
        OUT_FILE.write(line+"\n")
    else:
        print(line)


def nextLine():
    global IN_FILE_OPENED
    global IN_FILE
    if READ_FILE:
        if not IN_FILE_OPENED:
            IN_FILE = open(IN_FILE_NAME, "r")
            IN_FILE_OPENED = True
        line = IN_FILE.readline().strip()
    else:
        line = input()
    return line
            

main()
